@@ -1,17 +1,7 @@
-/*
-  * Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-  *
-  * Licensed under the Apache License, Version 2.0 (the "License").
-  * You may not use this file except in compliance with the License.
-  * A copy of the License is located at
-  *
-  *  http://aws.amazon.com/apache2.0
-  *
-  * or in the "license" file accompanying this file. This file is distributed
-  * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-  * express or implied. See the License for the specific language governing
-  * permissions and limitations under the License.
-  */
+/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 
@@ -79,7 +69,7 @@ namespace Aws
              * Initializes an HttpRequest object with uri and http method.
              */
             HttpRequest(const URI& uri, HttpMethod method) :
-                m_uri(uri), m_method(method)
+                m_uri(uri), m_method(method), m_isEvenStreamRequest(false)
             {}
 
             virtual ~HttpRequest() {}
@@ -533,9 +523,12 @@ namespace Aws
             Aws::String GetResolvedRemoteHost() const { return m_resolvedRemoteHost; }
             void SetResolvedRemoteHost(const Aws::String& ip) { m_resolvedRemoteHost = ip; }
 
+            bool IsEventStreamRequest() { return m_isEvenStreamRequest; }
+            void SetEventStreamRequest(bool eventStreamRequest) { m_isEvenStreamRequest = eventStreamRequest; }
         private:
             URI m_uri;
             HttpMethod m_method;
+            bool m_isEvenStreamRequest;
             DataReceivedEventHandler m_onDataReceived;
             DataSentEventHandler m_onDataSent;
             ContinueRequestHandler m_continueRequest;
@@ -547,6 +540,3 @@ namespace Aws
 
     } // namespace Http
 } // namespace Aws
-
-
-
