@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -54,8 +44,8 @@ namespace Model
      * <p>Indicates whether the EBS volume is deleted on instance termination. For more
      * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#preserving-volumes-on-termination">Preserving
-     * Amazon EBS Volumes on Instance Termination</a> in the Amazon Elastic Compute
-     * Cloud User Guide.</p>
+     * Amazon EBS volumes on instance termination</a> in the <i>Amazon EC2 User
+     * Guide</i>.</p>
      */
     inline bool GetDeleteOnTermination() const{ return m_deleteOnTermination; }
 
@@ -63,8 +53,8 @@ namespace Model
      * <p>Indicates whether the EBS volume is deleted on instance termination. For more
      * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#preserving-volumes-on-termination">Preserving
-     * Amazon EBS Volumes on Instance Termination</a> in the Amazon Elastic Compute
-     * Cloud User Guide.</p>
+     * Amazon EBS volumes on instance termination</a> in the <i>Amazon EC2 User
+     * Guide</i>.</p>
      */
     inline bool DeleteOnTerminationHasBeenSet() const { return m_deleteOnTerminationHasBeenSet; }
 
@@ -72,8 +62,8 @@ namespace Model
      * <p>Indicates whether the EBS volume is deleted on instance termination. For more
      * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#preserving-volumes-on-termination">Preserving
-     * Amazon EBS Volumes on Instance Termination</a> in the Amazon Elastic Compute
-     * Cloud User Guide.</p>
+     * Amazon EBS volumes on instance termination</a> in the <i>Amazon EC2 User
+     * Guide</i>.</p>
      */
     inline void SetDeleteOnTermination(bool value) { m_deleteOnTerminationHasBeenSet = true; m_deleteOnTermination = value; }
 
@@ -81,97 +71,89 @@ namespace Model
      * <p>Indicates whether the EBS volume is deleted on instance termination. For more
      * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#preserving-volumes-on-termination">Preserving
-     * Amazon EBS Volumes on Instance Termination</a> in the Amazon Elastic Compute
-     * Cloud User Guide.</p>
+     * Amazon EBS volumes on instance termination</a> in the <i>Amazon EC2 User
+     * Guide</i>.</p>
      */
     inline EbsBlockDevice& WithDeleteOnTermination(bool value) { SetDeleteOnTermination(value); return *this;}
 
 
     /**
-     * <p>The number of I/O operations per second (IOPS) that the volume supports. For
-     * <code>io1</code> volumes, this represents the number of IOPS that are
-     * provisioned for the volume. For <code>gp2</code> volumes, this represents the
-     * baseline performance of the volume and the rate at which the volume accumulates
-     * I/O credits for bursting. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Constraints: Range is 100-16,000 IOPS for <code>gp2</code> volumes and 100 to
-     * 64,000IOPS for <code>io1</code> volumes in most Regions. Maximum
-     * <code>io1</code> IOPS of 64,000 is guaranteed only on <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
-     * instances</a>. Other instance families guarantee performance up to 32,000 IOPS.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Condition: This parameter is required for requests to create <code>io1</code>
-     * volumes; it is not used in requests to create <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code> volumes.</p>
+     * <p>The number of I/O operations per second (IOPS). For <code>gp3</code>,
+     * <code>io1</code>, and <code>io2</code> volumes, this represents the number of
+     * IOPS that are provisioned for the volume. For <code>gp2</code> volumes, this
+     * represents the baseline performance of the volume and the rate at which the
+     * volume accumulates I/O credits for bursting.</p> <p>The following are the
+     * supported values for each volume type:</p> <ul> <li> <p> <code>gp3</code>:
+     * 3,000-16,000 IOPS</p> </li> <li> <p> <code>io1</code>: 100-64,000 IOPS</p> </li>
+     * <li> <p> <code>io2</code>: 100-64,000 IOPS</p> </li> </ul> <p>For
+     * <code>io1</code> and <code>io2</code> volumes, we guarantee 64,000 IOPS only for
+     * <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Instances
+     * built on the Nitro System</a>. Other instance families guarantee performance up
+     * to 32,000 IOPS.</p> <p>This parameter is required for <code>io1</code> and
+     * <code>io2</code> volumes. The default for <code>gp3</code> volumes is 3,000
+     * IOPS. This parameter is not supported for <code>gp2</code>, <code>st1</code>,
+     * <code>sc1</code>, or <code>standard</code> volumes.</p>
      */
     inline int GetIops() const{ return m_iops; }
 
     /**
-     * <p>The number of I/O operations per second (IOPS) that the volume supports. For
-     * <code>io1</code> volumes, this represents the number of IOPS that are
-     * provisioned for the volume. For <code>gp2</code> volumes, this represents the
-     * baseline performance of the volume and the rate at which the volume accumulates
-     * I/O credits for bursting. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Constraints: Range is 100-16,000 IOPS for <code>gp2</code> volumes and 100 to
-     * 64,000IOPS for <code>io1</code> volumes in most Regions. Maximum
-     * <code>io1</code> IOPS of 64,000 is guaranteed only on <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
-     * instances</a>. Other instance families guarantee performance up to 32,000 IOPS.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Condition: This parameter is required for requests to create <code>io1</code>
-     * volumes; it is not used in requests to create <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code> volumes.</p>
+     * <p>The number of I/O operations per second (IOPS). For <code>gp3</code>,
+     * <code>io1</code>, and <code>io2</code> volumes, this represents the number of
+     * IOPS that are provisioned for the volume. For <code>gp2</code> volumes, this
+     * represents the baseline performance of the volume and the rate at which the
+     * volume accumulates I/O credits for bursting.</p> <p>The following are the
+     * supported values for each volume type:</p> <ul> <li> <p> <code>gp3</code>:
+     * 3,000-16,000 IOPS</p> </li> <li> <p> <code>io1</code>: 100-64,000 IOPS</p> </li>
+     * <li> <p> <code>io2</code>: 100-64,000 IOPS</p> </li> </ul> <p>For
+     * <code>io1</code> and <code>io2</code> volumes, we guarantee 64,000 IOPS only for
+     * <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Instances
+     * built on the Nitro System</a>. Other instance families guarantee performance up
+     * to 32,000 IOPS.</p> <p>This parameter is required for <code>io1</code> and
+     * <code>io2</code> volumes. The default for <code>gp3</code> volumes is 3,000
+     * IOPS. This parameter is not supported for <code>gp2</code>, <code>st1</code>,
+     * <code>sc1</code>, or <code>standard</code> volumes.</p>
      */
     inline bool IopsHasBeenSet() const { return m_iopsHasBeenSet; }
 
     /**
-     * <p>The number of I/O operations per second (IOPS) that the volume supports. For
-     * <code>io1</code> volumes, this represents the number of IOPS that are
-     * provisioned for the volume. For <code>gp2</code> volumes, this represents the
-     * baseline performance of the volume and the rate at which the volume accumulates
-     * I/O credits for bursting. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Constraints: Range is 100-16,000 IOPS for <code>gp2</code> volumes and 100 to
-     * 64,000IOPS for <code>io1</code> volumes in most Regions. Maximum
-     * <code>io1</code> IOPS of 64,000 is guaranteed only on <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
-     * instances</a>. Other instance families guarantee performance up to 32,000 IOPS.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Condition: This parameter is required for requests to create <code>io1</code>
-     * volumes; it is not used in requests to create <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code> volumes.</p>
+     * <p>The number of I/O operations per second (IOPS). For <code>gp3</code>,
+     * <code>io1</code>, and <code>io2</code> volumes, this represents the number of
+     * IOPS that are provisioned for the volume. For <code>gp2</code> volumes, this
+     * represents the baseline performance of the volume and the rate at which the
+     * volume accumulates I/O credits for bursting.</p> <p>The following are the
+     * supported values for each volume type:</p> <ul> <li> <p> <code>gp3</code>:
+     * 3,000-16,000 IOPS</p> </li> <li> <p> <code>io1</code>: 100-64,000 IOPS</p> </li>
+     * <li> <p> <code>io2</code>: 100-64,000 IOPS</p> </li> </ul> <p>For
+     * <code>io1</code> and <code>io2</code> volumes, we guarantee 64,000 IOPS only for
+     * <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Instances
+     * built on the Nitro System</a>. Other instance families guarantee performance up
+     * to 32,000 IOPS.</p> <p>This parameter is required for <code>io1</code> and
+     * <code>io2</code> volumes. The default for <code>gp3</code> volumes is 3,000
+     * IOPS. This parameter is not supported for <code>gp2</code>, <code>st1</code>,
+     * <code>sc1</code>, or <code>standard</code> volumes.</p>
      */
     inline void SetIops(int value) { m_iopsHasBeenSet = true; m_iops = value; }
 
     /**
-     * <p>The number of I/O operations per second (IOPS) that the volume supports. For
-     * <code>io1</code> volumes, this represents the number of IOPS that are
-     * provisioned for the volume. For <code>gp2</code> volumes, this represents the
-     * baseline performance of the volume and the rate at which the volume accumulates
-     * I/O credits for bursting. For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Constraints: Range is 100-16,000 IOPS for <code>gp2</code> volumes and 100 to
-     * 64,000IOPS for <code>io1</code> volumes in most Regions. Maximum
-     * <code>io1</code> IOPS of 64,000 is guaranteed only on <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Nitro-based
-     * instances</a>. Other instance families guarantee performance up to 32,000 IOPS.
-     * For more information, see <a
-     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
-     * EBS Volume Types</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>Condition: This parameter is required for requests to create <code>io1</code>
-     * volumes; it is not used in requests to create <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code> volumes.</p>
+     * <p>The number of I/O operations per second (IOPS). For <code>gp3</code>,
+     * <code>io1</code>, and <code>io2</code> volumes, this represents the number of
+     * IOPS that are provisioned for the volume. For <code>gp2</code> volumes, this
+     * represents the baseline performance of the volume and the rate at which the
+     * volume accumulates I/O credits for bursting.</p> <p>The following are the
+     * supported values for each volume type:</p> <ul> <li> <p> <code>gp3</code>:
+     * 3,000-16,000 IOPS</p> </li> <li> <p> <code>io1</code>: 100-64,000 IOPS</p> </li>
+     * <li> <p> <code>io2</code>: 100-64,000 IOPS</p> </li> </ul> <p>For
+     * <code>io1</code> and <code>io2</code> volumes, we guarantee 64,000 IOPS only for
+     * <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances">Instances
+     * built on the Nitro System</a>. Other instance families guarantee performance up
+     * to 32,000 IOPS.</p> <p>This parameter is required for <code>io1</code> and
+     * <code>io2</code> volumes. The default for <code>gp3</code> volumes is 3,000
+     * IOPS. This parameter is not supported for <code>gp2</code>, <code>st1</code>,
+     * <code>sc1</code>, or <code>standard</code> volumes.</p>
      */
     inline EbsBlockDevice& WithIops(int value) { SetIops(value); return *this;}
 
@@ -218,95 +200,105 @@ namespace Model
 
 
     /**
-     * <p>The size of the volume, in GiB.</p> <p>Default: If you're creating the volume
-     * from a snapshot and don't specify a volume size, the default is the snapshot
-     * size.</p> <p>Constraints: 1-16384 for General Purpose SSD (<code>gp2</code>),
-     * 4-16384 for Provisioned IOPS SSD (<code>io1</code>), 500-16384 for Throughput
-     * Optimized HDD (<code>st1</code>), 500-16384 for Cold HDD (<code>sc1</code>), and
-     * 1-1024 for Magnetic (<code>standard</code>) volumes. If you specify a snapshot,
-     * the volume size must be equal to or larger than the snapshot size.</p>
+     * <p>The size of the volume, in GiBs. You must specify either a snapshot ID or a
+     * volume size. If you specify a snapshot, the default is the snapshot size. You
+     * can specify a volume size that is equal to or larger than the snapshot size.</p>
+     * <p>The following are the supported volumes sizes for each volume type:</p> <ul>
+     * <li> <p> <code>gp2</code> and <code>gp3</code>:1-16,384</p> </li> <li> <p>
+     * <code>io1</code> and <code>io2</code>: 4-16,384</p> </li> <li> <p>
+     * <code>st1</code> and <code>sc1</code>: 125-16,384</p> </li> <li> <p>
+     * <code>standard</code>: 1-1,024</p> </li> </ul>
      */
     inline int GetVolumeSize() const{ return m_volumeSize; }
 
     /**
-     * <p>The size of the volume, in GiB.</p> <p>Default: If you're creating the volume
-     * from a snapshot and don't specify a volume size, the default is the snapshot
-     * size.</p> <p>Constraints: 1-16384 for General Purpose SSD (<code>gp2</code>),
-     * 4-16384 for Provisioned IOPS SSD (<code>io1</code>), 500-16384 for Throughput
-     * Optimized HDD (<code>st1</code>), 500-16384 for Cold HDD (<code>sc1</code>), and
-     * 1-1024 for Magnetic (<code>standard</code>) volumes. If you specify a snapshot,
-     * the volume size must be equal to or larger than the snapshot size.</p>
+     * <p>The size of the volume, in GiBs. You must specify either a snapshot ID or a
+     * volume size. If you specify a snapshot, the default is the snapshot size. You
+     * can specify a volume size that is equal to or larger than the snapshot size.</p>
+     * <p>The following are the supported volumes sizes for each volume type:</p> <ul>
+     * <li> <p> <code>gp2</code> and <code>gp3</code>:1-16,384</p> </li> <li> <p>
+     * <code>io1</code> and <code>io2</code>: 4-16,384</p> </li> <li> <p>
+     * <code>st1</code> and <code>sc1</code>: 125-16,384</p> </li> <li> <p>
+     * <code>standard</code>: 1-1,024</p> </li> </ul>
      */
     inline bool VolumeSizeHasBeenSet() const { return m_volumeSizeHasBeenSet; }
 
     /**
-     * <p>The size of the volume, in GiB.</p> <p>Default: If you're creating the volume
-     * from a snapshot and don't specify a volume size, the default is the snapshot
-     * size.</p> <p>Constraints: 1-16384 for General Purpose SSD (<code>gp2</code>),
-     * 4-16384 for Provisioned IOPS SSD (<code>io1</code>), 500-16384 for Throughput
-     * Optimized HDD (<code>st1</code>), 500-16384 for Cold HDD (<code>sc1</code>), and
-     * 1-1024 for Magnetic (<code>standard</code>) volumes. If you specify a snapshot,
-     * the volume size must be equal to or larger than the snapshot size.</p>
+     * <p>The size of the volume, in GiBs. You must specify either a snapshot ID or a
+     * volume size. If you specify a snapshot, the default is the snapshot size. You
+     * can specify a volume size that is equal to or larger than the snapshot size.</p>
+     * <p>The following are the supported volumes sizes for each volume type:</p> <ul>
+     * <li> <p> <code>gp2</code> and <code>gp3</code>:1-16,384</p> </li> <li> <p>
+     * <code>io1</code> and <code>io2</code>: 4-16,384</p> </li> <li> <p>
+     * <code>st1</code> and <code>sc1</code>: 125-16,384</p> </li> <li> <p>
+     * <code>standard</code>: 1-1,024</p> </li> </ul>
      */
     inline void SetVolumeSize(int value) { m_volumeSizeHasBeenSet = true; m_volumeSize = value; }
 
     /**
-     * <p>The size of the volume, in GiB.</p> <p>Default: If you're creating the volume
-     * from a snapshot and don't specify a volume size, the default is the snapshot
-     * size.</p> <p>Constraints: 1-16384 for General Purpose SSD (<code>gp2</code>),
-     * 4-16384 for Provisioned IOPS SSD (<code>io1</code>), 500-16384 for Throughput
-     * Optimized HDD (<code>st1</code>), 500-16384 for Cold HDD (<code>sc1</code>), and
-     * 1-1024 for Magnetic (<code>standard</code>) volumes. If you specify a snapshot,
-     * the volume size must be equal to or larger than the snapshot size.</p>
+     * <p>The size of the volume, in GiBs. You must specify either a snapshot ID or a
+     * volume size. If you specify a snapshot, the default is the snapshot size. You
+     * can specify a volume size that is equal to or larger than the snapshot size.</p>
+     * <p>The following are the supported volumes sizes for each volume type:</p> <ul>
+     * <li> <p> <code>gp2</code> and <code>gp3</code>:1-16,384</p> </li> <li> <p>
+     * <code>io1</code> and <code>io2</code>: 4-16,384</p> </li> <li> <p>
+     * <code>st1</code> and <code>sc1</code>: 125-16,384</p> </li> <li> <p>
+     * <code>standard</code>: 1-1,024</p> </li> </ul>
      */
     inline EbsBlockDevice& WithVolumeSize(int value) { SetVolumeSize(value); return *this;}
 
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline const VolumeType& GetVolumeType() const{ return m_volumeType; }
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline bool VolumeTypeHasBeenSet() const { return m_volumeTypeHasBeenSet; }
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline void SetVolumeType(const VolumeType& value) { m_volumeTypeHasBeenSet = true; m_volumeType = value; }
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline void SetVolumeType(VolumeType&& value) { m_volumeTypeHasBeenSet = true; m_volumeType = std::move(value); }
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline EbsBlockDevice& WithVolumeType(const VolumeType& value) { SetVolumeType(value); return *this;}
 
     /**
-     * <p>The volume type. If you set the type to <code>io1</code>, you must also
-     * specify the <b>Iops</b> parameter. If you set the type to <code>gp2</code>,
-     * <code>st1</code>, <code>sc1</code>, or <code>standard</code>, you must omit the
-     * <b>Iops</b> parameter.</p> <p>Default: <code>gp2</code> </p>
+     * <p>The volume type. For more information, see <a
+     * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html">Amazon
+     * EBS volume types</a> in the <i>Amazon EC2 User Guide</i>. If the volume type is
+     * <code>io1</code> or <code>io2</code>, you must specify the IOPS that the volume
+     * supports.</p>
      */
     inline EbsBlockDevice& WithVolumeType(VolumeType&& value) { SetVolumeType(std::move(value)); return *this;}
 
@@ -408,6 +400,35 @@ namespace Model
     inline EbsBlockDevice& WithKmsKeyId(const char* value) { SetKmsKeyId(value); return *this;}
 
 
+    /**
+     * <p>The throughput that the volume supports, in MiB/s.</p> <p>This parameter is
+     * valid only for <code>gp3</code> volumes.</p> <p>Valid Range: Minimum value of
+     * 125. Maximum value of 1000.</p>
+     */
+    inline int GetThroughput() const{ return m_throughput; }
+
+    /**
+     * <p>The throughput that the volume supports, in MiB/s.</p> <p>This parameter is
+     * valid only for <code>gp3</code> volumes.</p> <p>Valid Range: Minimum value of
+     * 125. Maximum value of 1000.</p>
+     */
+    inline bool ThroughputHasBeenSet() const { return m_throughputHasBeenSet; }
+
+    /**
+     * <p>The throughput that the volume supports, in MiB/s.</p> <p>This parameter is
+     * valid only for <code>gp3</code> volumes.</p> <p>Valid Range: Minimum value of
+     * 125. Maximum value of 1000.</p>
+     */
+    inline void SetThroughput(int value) { m_throughputHasBeenSet = true; m_throughput = value; }
+
+    /**
+     * <p>The throughput that the volume supports, in MiB/s.</p> <p>This parameter is
+     * valid only for <code>gp3</code> volumes.</p> <p>Valid Range: Minimum value of
+     * 125. Maximum value of 1000.</p>
+     */
+    inline EbsBlockDevice& WithThroughput(int value) { SetThroughput(value); return *this;}
+
+
     /**
      * <p>Indicates whether the encryption state of an EBS volume is changed while
      * being restored from a backing snapshot. The effect of setting the encryption
@@ -415,12 +436,12 @@ namespace Model
      * snapshot), starting encryption state, ownership, and whether encryption by
      * default is enabled. For more information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#encryption-parameters">Amazon
-     * EBS Encryption</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>In no case can you remove encryption from an encrypted volume.</p>
-     * <p>Encrypted volumes can only be attached to instances that support Amazon EBS
-     * encryption. For more information, see <a
+     * EBS encryption</a> in the <i>Amazon EC2 User Guide</i>.</p> <p>In no case can
+     * you remove encryption from an encrypted volume.</p> <p>Encrypted volumes can
+     * only be attached to instances that support Amazon EBS encryption. For more
+     * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances">Supported
-     * Instance Types</a>.</p> <p>This parameter is not returned by .</p>
+     * instance types</a>.</p> <p>This parameter is not returned by .</p>
      */
     inline bool GetEncrypted() const{ return m_encrypted; }
 
@@ -431,12 +452,12 @@ namespace Model
      * snapshot), starting encryption state, ownership, and whether encryption by
      * default is enabled. For more information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#encryption-parameters">Amazon
-     * EBS Encryption</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>In no case can you remove encryption from an encrypted volume.</p>
-     * <p>Encrypted volumes can only be attached to instances that support Amazon EBS
-     * encryption. For more information, see <a
+     * EBS encryption</a> in the <i>Amazon EC2 User Guide</i>.</p> <p>In no case can
+     * you remove encryption from an encrypted volume.</p> <p>Encrypted volumes can
+     * only be attached to instances that support Amazon EBS encryption. For more
+     * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances">Supported
-     * Instance Types</a>.</p> <p>This parameter is not returned by .</p>
+     * instance types</a>.</p> <p>This parameter is not returned by .</p>
      */
     inline bool EncryptedHasBeenSet() const { return m_encryptedHasBeenSet; }
 
@@ -447,12 +468,12 @@ namespace Model
      * snapshot), starting encryption state, ownership, and whether encryption by
      * default is enabled. For more information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#encryption-parameters">Amazon
-     * EBS Encryption</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>In no case can you remove encryption from an encrypted volume.</p>
-     * <p>Encrypted volumes can only be attached to instances that support Amazon EBS
-     * encryption. For more information, see <a
+     * EBS encryption</a> in the <i>Amazon EC2 User Guide</i>.</p> <p>In no case can
+     * you remove encryption from an encrypted volume.</p> <p>Encrypted volumes can
+     * only be attached to instances that support Amazon EBS encryption. For more
+     * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances">Supported
-     * Instance Types</a>.</p> <p>This parameter is not returned by .</p>
+     * instance types</a>.</p> <p>This parameter is not returned by .</p>
      */
     inline void SetEncrypted(bool value) { m_encryptedHasBeenSet = true; m_encrypted = value; }
 
@@ -463,12 +484,12 @@ namespace Model
      * snapshot), starting encryption state, ownership, and whether encryption by
      * default is enabled. For more information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#encryption-parameters">Amazon
-     * EBS Encryption</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
-     * <p>In no case can you remove encryption from an encrypted volume.</p>
-     * <p>Encrypted volumes can only be attached to instances that support Amazon EBS
-     * encryption. For more information, see <a
+     * EBS encryption</a> in the <i>Amazon EC2 User Guide</i>.</p> <p>In no case can
+     * you remove encryption from an encrypted volume.</p> <p>Encrypted volumes can
+     * only be attached to instances that support Amazon EBS encryption. For more
+     * information, see <a
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances">Supported
-     * Instance Types</a>.</p> <p>This parameter is not returned by .</p>
+     * instance types</a>.</p> <p>This parameter is not returned by .</p>
      */
     inline EbsBlockDevice& WithEncrypted(bool value) { SetEncrypted(value); return *this;}
 
@@ -492,6 +513,9 @@ namespace Model
     Aws::String m_kmsKeyId;
     bool m_kmsKeyIdHasBeenSet;
 
+    int m_throughput;
+    bool m_throughputHasBeenSet;
+
     bool m_encrypted;
     bool m_encryptedHasBeenSet;
   };
